# Environments

The Space Robotics Bench provides a variety of environments that simulate diverse scenarios in the challenging domain of space:

- [**Manipulation**](manipulation.md) - Stationary manipulation skills and sequences in various contexts
- [**Mobile Robotics**](mobile_robotics.md) - Traversal and navigation under extraterrestrial conditions
- [**Mobile Manipulation**](mobile_manipulation.md) - Complex combination of mobility and manipulation
